@@ -1,10 +1,11 @@
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 
 from oda_data.classes.oda_data import ODAData
 from oda_data.get_data.crs import download_crs
 from oda_data.get_data.dac1 import download_dac1
 from oda_data.get_data.dac2a import download_dac2a
 from oda_data.get_data.multisystem import download_multisystem
+from pydeflate import set_pydeflate_path
 
 
 def set_data_path(path):
@@ -15,3 +16,4 @@ def set_data_path(path):
     global OdaPATHS
 
     OdaPATHS.raw_data = Path(path).resolve()
+    set_pydeflate_path(OdaPATHS.raw_data)
